@@ -2,7 +2,7 @@
 #
 # «core» - Abstract lirc creator
 #
-# Copyright (C) 2007, Mario Limonciello, for Mythbuntu
+# Copyright (C) 2007-2008, Mario Limonciello, for Mythbuntu
 # Copyright (C) 2007, Nick Fox, for Mythbuntu
 #
 #
@@ -86,15 +86,19 @@ class ProgramHandler():
 
     def generate(self):
         """Generates a config for this program type"""
-        def parse_lircd():
+        def parse_lircd(file):
             """Reads in a lircd.conf and returns all buttons found"""
-            in_f=open(self.lircd).readlines()
+            in_f=open(file).readlines()
             filterpattern = re.compile("^#")
             remotes = {}
             codes=False
             remotename=""
             for line in in_f:
                 if filterpattern.search(line) is None:
+                    if re.compile("^include").search(line) is not None:
+                        sub_remotes = parse_lircd(string.split(line)[1])
+                        for remotename,codes in sub_remotes.iteritems():
+                            remotes[remotename]=codes
                     if not codes:
                         if re.compile("name").search(line) is not None:
                             list = string.split(line)
@@ -112,8 +116,9 @@ class ProgramHandler():
                                 #buttons[list[0]] = remotename
                                 remotes[remotename].append(list[0])
             return remotes
-        self.remotes = parse_lircd()
+        self.remotes = parse_lircd(self.lircd)
         out_f = open(self.lircrc,'a')
+        out_f.write("# LIRCRC Auto Generated by Mythbuntu Lirc Generator\n# Author(s): Mario Limonciello, Nick Fox\n# Created for use with Mythbuntu\n")
         self.match_dictionary(out_f)
         out_f.close()
 
@@ -153,12 +158,13 @@ class ProgramHandler():
 
 
     def write_key(self,stream,function,button,remote):
-        stream.write("begin\n")
+    	"""Writes a key block"""
+    	stream.write("begin\n")
         stream.write("    remote = " + remote +                "\n")
         stream.write("    prog = "   + self.application_name + "\n")
         stream.write("    button = " + button +                "\n")
         stream.write("    config = " + function +              "\n")
-        stream.write("    repeat = " + self.repeat +           "\n") 
+        stream.write("    repeat = " + self.repeat +           "\n")
         stream.write("    delay = " + self.delay +             "\n")
         stream.write("end\n")
         stream.write("\n")
